#-------------------------------------------------------------------------------
# Copyright (c) 1997-2007, Perforce Software, Inc.  All rights reserved. 
#  
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met: 
#  
# 1.  Redistributions of source code must retain the above copyright 
#     notice, this list of conditions and the following disclaimer. 
#  
# 2.  Redistributions in binary form must reproduce the above copyright 
#     notice, this list of conditions and the following disclaimer in the 
#     documentation and/or other materials provided with the distribution. 
#  
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS  
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS  
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE  
# SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,  
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT  
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON  
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR  
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF  
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH  
# DAMAGE. 
#-------------------------------------------------------------------------------

class TC_Specs < Test::Unit::TestCase

    include P4RubyTest

    def name
	"Test spec parsing"
    end

    def test_specs
	jobspec = \
"Fields:
        101 Job word 32 required
        102 Status select 10 required
        103 User word 32 required
        104 Date date 20 always
        105 Description text 0 required
	106 Field1 text 0 optional

Values:
        Status open/suspended/closed

Presets:
        Status open
        User $user
        Date $now
        Description $blank
"

	assert( p4.connect, "Failed to connect to Perforce server" )

	p4.save_jobspec( jobspec );
	job = p4.fetch_job
	job._field1 = 'some text'
	job._description = 'some more text'

	o = p4.save_job( job )
	assert( o.length == 1 )
	assert_equal( o[ 0 ], 'Job job000001 saved.' )

	spec = p4.fetch_jobspec
	assert( spec.class == P4::Spec )
	spec = p4.format_jobspec( spec )
	assert( spec.class == String )
	spec = p4.parse_jobspec( spec )
	assert( spec.class == P4::Spec )

	spec = p4.fetch_job( 'job000001' )
	assert( spec.has_key?( 'Field1' ) )
	p4.disconnect
    end
end
